Struct ZwpTabletPadRingV2
pub struct ZwpTabletPadRingV2 { /* private fields */ }wayland and Linux only.Expand description
pad ring
A circular interaction area, such as the touch ring on the Wacom Intuos Pro series tablets.
Events on a ring are logically grouped by the zwp_tablet_pad_ring_v2.frame event.
See also the Request enum for this interface.
Implementations
impl ZwpTabletPadRingV2
impl ZwpTabletPadRingV2
pub fn source(&self, source: Source)
pub fn source(&self, source: Source)
ring event source
Source information for ring events.
This event does not occur on its own. It is sent before a zwp_tablet_pad_ring_v2.frame event and carries the source information for all events within that frame.
The source specifies how this event was generated. If the source is zwp_tablet_pad_ring_v2.source.finger, a zwp_tablet_pad_ring_v2.stop event will be sent when the user lifts the finger off the device.
This event is optional. If the source is unknown for an interaction, no event is sent.
pub fn angle(&self, degrees: f64)
pub fn angle(&self, degrees: f64)
angle changed
Sent whenever the angle on a ring changes.
The angle is provided in degrees clockwise from the logical north of the ring in the pad’s current rotation.
pub fn stop(&self)
pub fn stop(&self)
interaction stopped
Stop notification for ring events.
For some zwp_tablet_pad_ring_v2.source types, a zwp_tablet_pad_ring_v2.stop event is sent to notify a client that the interaction with the ring has terminated. This enables the client to implement kinetic scrolling. See the zwp_tablet_pad_ring_v2.source documentation for information on when this event may be generated.
Any zwp_tablet_pad_ring_v2.angle events with the same source after this event should be considered as the start of a new interaction.
pub fn frame(&self, time: u32)
pub fn frame(&self, time: u32)
end of a ring event sequence
Indicates the end of a set of ring events that logically belong together. A client is expected to accumulate the data in all events within the frame before proceeding.
All zwp_tablet_pad_ring_v2 events before a zwp_tablet_pad_ring_v2.frame event belong logically together. For example, on termination of a finger interaction on a ring the compositor will send a zwp_tablet_pad_ring_v2.source event, a zwp_tablet_pad_ring_v2.stop event and a zwp_tablet_pad_ring_v2.frame event.
A zwp_tablet_pad_ring_v2.frame event is sent for every logical event group, even if the group only contains a single zwp_tablet_pad_ring_v2 event. Specifically, a client may get a sequence: angle, frame, angle, frame, etc.